@@ -1023,7 +1023,7 @@ void TestCli::testInfo()
     QCOMPARE(m_stdout->readLine(), QByteArray("Number of short passwords: 0\n"));
     QCOMPARE(m_stdout->readLine(), QByteArray("Number of weak passwords: 2\n"));
     QCOMPARE(m_stdout->readLine(), QByteArray("Entries excluded from reports: 0\n"));
-    QCOMPARE(m_stdout->readLine(), QByteArray("Average password length: 11 characters\n"));
+    QCOMPARE(m_stdout->readLine(), QByteArray("Average password length: 11 character(s)\n"));
 
     // Test with quiet option.
     setInput("a");
@@ -1086,8 +1086,9 @@ void TestCli::testDiceware()
     }
     smallWordFile.close();
 
+    // Ensure a warning is shown if the wordlist is too short
     execCmd(dicewareCmd, {"diceware", "-W", "11", "-w", smallWordFile.fileName()});
-    QCOMPARE(m_stderr->readLine(), QByteArray("Cannot generate valid passphrases because the wordlist is too short\n"));
+    QVERIFY(m_stderr->readLine().length() > 0);
 }
 
 void TestCli::testEdit()
@@ -1678,8 +1679,9 @@ void TestCli::testMerge()
     m_stderr->readLine(); // Skip password prompt
     QCOMPARE(m_stderr->readAll(), QByteArray());
     QList<QByteArray> outLines1 = m_stdout->readAll().split('\n');
-    QVERIFY(outLines1.at(0).contains("Overwriting Internet"));
-    QVERIFY(outLines1.at(1).contains("Creating missing Some Website"));
+    QVERIFY(outLines1.at(0).contains("Modified"));
+    QVERIFY(outLines1.at(0).contains("Modification time"));
+    QVERIFY(outLines1.at(1).contains("Added"));
     QCOMPARE(outLines1.at(2),
              QString("Successfully merged %1 into %2.").arg(sourceFile.fileName(), targetFile1.fileName()).toUtf8());
 
@@ -1695,8 +1697,9 @@ void TestCli::testMerge()
     setInput("a");
     execCmd(mergeCmd, {"merge", "--dry-run", "-s", targetFile2.fileName(), sourceFile.fileName()});
     QList<QByteArray> outLines2 = m_stdout->readAll().split('\n');
-    QVERIFY(outLines2.at(0).contains("Overwriting Internet"));
-    QVERIFY(outLines2.at(1).contains("Creating missing Some Website"));
+    QVERIFY(outLines1.at(0).contains("Modified"));
+    QVERIFY(outLines1.at(0).contains("Modification time"));
+    QVERIFY(outLines2.at(1).contains("Added"));
     QCOMPARE(outLines2.at(2), QByteArray("Database was not modified by merge operation."));
 
     mergedDb = QSharedPointer<Database>::create();
